@@ -66,4 +66,4 @@ def run():
     #    view = responder.ext.GraphQLView(api=server.api, schema=schema)
     #    server.api.add_route(mountpoint, view)
 
-    # server.run()
+    server.run()
