@@ -5,11 +5,14 @@ from responder.core import Request, Response
 
 from digicubes_rest.storage.models import User
 
-from .util import BasicRessource, error_response, needs_bearer_token
+from .util import BasicRessource, error_response, needs_bearer_token, BluePrint
 
 logger = logging.getLogger(__name__)  # pylint: disable=C0103
+me_schools_blueprint = BluePrint()
+route = me_schools_blueprint.route
 
 
+@route("/me/schools/")
 class MeSchoolsRessource(BasicRessource):
     """
     Get all schools of the current user. These are the schools,
