@@ -4,14 +4,19 @@ import logging
 from responder.core import Request, Response
 from tortoise.exceptions import DoesNotExist, IntegrityError
 
-from digicubes_common.entities import RightEntity
 from digicubes_rest.storage.models import User
 
-from .util import BasicRessource, error_response, needs_int_parameter, needs_bearer_token
+from digicubes_rest.storage import models
+from .util import BasicRessource, error_response, needs_int_parameter, needs_bearer_token, BluePrint
+
 
 logger = logging.getLogger(__name__)  # pylint: disable=C0103
 
+user_blueprint = BluePrint()
+route = user_blueprint.route
 
+
+@route("/user/{user_id}")
 class UserRessource(BasicRessource):
     """
     Endpoint for a user
@@ -20,7 +25,7 @@ class UserRessource(BasicRessource):
     ALLOWED_METHODS = "GET, PUT, DELETE"
 
     @needs_int_parameter("user_id")
-    @needs_bearer_token(RightEntity.CREATE_USER)
+    @needs_bearer_token()
     async def on_post(self, req: Request, resp: Response, *, user_id: int):
         """
         Method not allowed. Returns a list of allowed methods in the ``Allow``
@@ -32,7 +37,7 @@ class UserRessource(BasicRessource):
         resp.status_code = 405
 
     @needs_int_parameter("user_id")
-    @needs_bearer_token(RightEntity.READ_USER)
+    @needs_bearer_token()
     async def on_get(self, req: Request, resp: Response, *, user_id: int):
         """
         Get a user
@@ -55,7 +60,7 @@ class UserRessource(BasicRessource):
             error_response(resp, 500, str(error))
 
     @needs_int_parameter("user_id")
-    @needs_bearer_token(RightEntity.UPDATE_USER)
+    @needs_bearer_token()
     async def on_put(self, req: Request, resp: Response, *, user_id: int):
         """
         Updates a user. If the user does not exist, a 404 status is returned.
@@ -98,7 +103,7 @@ class UserRessource(BasicRessource):
             error_response(resp, 500, str(error))
 
     @needs_int_parameter("user_id")
-    @needs_bearer_token(RightEntity.DELETE_USER)
+    @needs_bearer_token()
     async def on_delete(self, req: Request, resp: Response, *, user_id: int):
         """
         Deletes a user from the database.
@@ -117,3 +122,18 @@ class UserRessource(BasicRessource):
 
         except Exception as error:  # pylint: disable=W0703
             error_response(resp, 500, str(error))
+
+
+@route("/user/bylogin/{data}")
+async def get_user_by_login(req: Request, resp: Response, *, data):
+    # pylint: disable=unused-variable
+    if req.method == "get":
+        user = await models.User.get_or_none(login=data)
+        if user is None:
+            resp.status_code = 404
+            resp.text = f"User with login {data} not found."
+        else:
+            resp.media = user.unstructure(exclude_fields=["password_hash"])
+    else:
+        resp.status_code = 405
+        resp.text = "Method not allowed"
