@@ -1,24 +1,152 @@
 # pylint: disable=C0111
 from datetime import datetime, timedelta
+from enum import IntEnum
 import logging
 from typing import Optional, List, Union
 
 import jwt
 from tortoise.models import Model
 from tortoise.exceptions import DoesNotExist
-from werkzeug import http
-from responder import Request, Response
+from tortoise.queryset import QuerySet
 
-from digicubes_common.exceptions import InsufficientRights
-from digicubes_common.entities import RightEntity
-from digicubes_common.structures import BearerTokenData
+from werkzeug import http
+from responder import Request, Response, API
+
+from digicubes_rest.exceptions import InsufficientRights
 from digicubes_rest.storage import models
 from digicubes_rest.storage.pools import UserPool
+from digicubes_rest.structures import BearerTokenData
 
 logger = logging.getLogger(__name__)  # pylint: disable=C0103
 # logger.setLevel(logging.DEBUG)
 
-TRights = Optional[Union[Union[RightEntity, str], List[Union[RightEntity, str]]]]
+
+class FilterFunction(IntEnum):
+
+    EQUAL = 0
+    IEQUAL = 1
+    STARTSWITH = 2
+    ISTARTSWITH = 3
+    ENDWITH = 4
+    IENDSWITH = 5
+    CONTAINS = 6
+    ICONTAINS = 7
+
+    def __str__(self):
+        return FilterFunction.to_name(self.value)
+
+    @staticmethod
+    def to_name(i: int):
+        return [
+            None,
+            "iequals",
+            "startswith",
+            "istartswith",
+            "endswith",
+            "iendswith",
+            "contains",
+            "icontains",
+        ][i]
+
+    def build(self, attribute: str):
+        return (
+            attribute
+            if self == FilterFunction.EQUAL
+            else f"{attribute}__{FilterFunction.to_name(self.value)}"
+        )
+
+
+def build_query_set(cls: Model, req: Request) -> QuerySet:
+    """
+    Creates a query base on the request information.
+
+    The filter fields have to be provided as the `f=` parameter of the request.
+    Es kann mehr, als ein filter Kriterium angegeben werden, die logisch mit einem
+    `und` verbunden sind. Jedes Filterkriterium besteht aus einem Tripel aus
+    Attribute, Filterfunktion und Filterwert. Die Werte des Tripel sind durch Komma,
+    und die Tripel durch Doppelpunkt voneinander getrennt.
+
+    Die Filterfunktionen werden durch ein Nummer angegeben. Folgende Funktionscodes
+    sind definiert.
+
+    EQUAL = 0
+    IEQUAL = 1
+    STARTSWITH = 2
+    ISTARTSWITH = 3
+    ENDWITH = 4
+    IENDSWITH = 5
+    CONTAINS = 6
+    ICONTAINS = 7
+
+    """
+    order = req.params.get("o", None)
+    page = req.params.get("p", None)
+    filter_params = req.params.get("f", None)
+    specials = req.params.get("s", "").split(",")
+
+    result: QuerySet = None
+    if filter_params:
+        filter_args = {}
+        for filter_entry in filter_params.split(":"):
+            attribute, filter_fn, value = filter_entry.split(",")
+            filter_args[FilterFunction(int(filter_fn)).build(attribute)] = value
+        result = models.User.filter(**filter_args)
+    else:
+        result = models.User.all()
+
+    # Check ordering
+    if order:
+        order_fields = order.split(",")
+        logger.info("Ordering by %r", order_fields)
+        result = result.order_by(*order_fields)
+
+    columns = req.params.get("c", None)
+    if columns:
+        logger.debug("Adding columns filter %s", columns)
+        result = result.only(*columns.split(","))
+
+    if "first" in specials:
+        result = result.first()
+
+    if "count" in specials:
+        result = result.count()
+
+    if page:
+        limit_offset = page.split(":")
+        if len(limit_offset) == 1:
+            result = result.limit(int(limit_offset[0]))
+            logger.debug("Adding limit %d to query.", int(limit_offset[0]))
+        elif len(limit_offset) == 2:
+            result = result.limit(int(limit_offset[0])).offset(int(limit_offset[1]))
+        else:
+            raise ValueError(f"Bad page param {page}")
+    return result
+
+
+class BluePrint:
+    def __init__(self, prefix=None):
+        self._prefix = prefix if prefix else ""
+        self._routes = []
+
+    def route(self, route: str, **options):
+        def decorator(f):
+            self._routes.append((route, f, options))
+            return f
+
+        return decorator
+
+    def register(self, api: API):
+        for route, endpoint, options in self._routes:
+            api.add_route(f"{self._prefix}{route}", endpoint, **options)
+
+    def __str__(self):
+        return f"Blueprint(prefix='{self._prefix}')"
+
+    def __repr__(self):
+        return f"Blueprint(prefix='{self._prefix}')"
+
+    def build_query_set(self, cls: Model, req: Request) -> QuerySet:
+        return build_query_set(cls, req)
 
 
 class needs_typed_parameter:
@@ -120,7 +248,6 @@ def decode_bearer_token(token: str, secret: str) -> str:
 
     :raises jwt.exceptions.ExpiredSignatureError: If the token is not valid anymore
     """
-    # TODO: Is it really str wich will be returned? What if the encoded payload was a dict?
     payload = jwt.decode(token, secret, algorithms=["HS256"])
     return payload
 
@@ -141,7 +268,7 @@ async def get_user_rights(user: models.User) -> List[str]:
     )
 
 
-async def check_rights(user: models.User, rights: List[Union[RightEntity, str]]) -> List[str]:
+async def check_rights(user: models.User, rights: List[str]) -> List[str]:
     """
     Returns the intersection of the user rights and the
     rights in the parameter rights.
@@ -170,7 +297,7 @@ async def has_right(user: models.User, rights: List[str]) -> bool:
     """
     Test, if the user has at least one of the rights.
     """
-    rights.append(RightEntity.ROOT_RIGHT.name)
+    rights.append("no_limits")
     return len(await check_rights(user, rights)) > 0
 
 
@@ -178,20 +305,20 @@ async def is_root(user: models.User) -> bool:
     """
     Test if the user has root rights.
     """
-    return await has_right(user, [RightEntity.ROOT_RIGHT])
+    return await has_right(user, ["no_limits"])
 
 
 class needs_bearer_token:
 
     __slots__ = ["rights"]
 
-    def __init__(self, rights: TRights = None) -> None:
+    def __init__(self, rights: List[str] = None) -> None:
         if rights is None:
             self.rights = None
-        elif isinstance(rights, (str, RightEntity)):
-            self.rights = [rights, RightEntity.ROOT_RIGHT]
+        elif isinstance(rights, str):
+            self.rights = [rights, "no_limits"]
         else:
-            self.rights = rights + [RightEntity.ROOT_RIGHT]
+            self.rights = rights + "no_limits"
 
     def __call__(self, f):  # pylint: disable=R0915
         async def wrapped_f(me, req: Request, resp: Response, *args, **kwargs):
@@ -266,15 +393,16 @@ class needs_bearer_token:
                             return await f(me, req, resp, *args, **kwargs)
 
                         except jwt.ExpiredSignatureError:
-                            logger.debug("Token expired")
+                            logger.exception("Token expired")
                             resp.text = "Token expired"
                         except jwt.DecodeError:
-                            logger.debug("Bad bearer token")
+                            logger.exception("Bad bearer token")
                             resp.text = "Bad bearer token"
                         except DoesNotExist:
-                            logger.debug("User does not exist")
+                            logger.exception("User does not exist")
                             resp.text = "No such user"
                         except InsufficientRights as error:
+                            logger.exception("InsuffitienRights")
                             resp.text = str(error)
                         except:
                             logger.critical("Unknown error", exc_info=True)
@@ -297,7 +425,6 @@ class needs_right:
 
     def __call__(self, f):
         async def wrapped_f(me, req, resp, *args, **kwargs):
-            print("inside wrapped")
             if "user_id" not in kwargs:
                 msg = "No user_id provided to check right '%s'. Got %s" % (
                     self.name,
